@@ -10,8 +10,8 @@ import pytest
 
 
 @pytest.fixture(scope="function", autouse=True)
-def suppressing():
-    """helper function adjusting message reporting for all tests"""
+def setup_and_teardown():
+    """helper function adjusting environment before and after tests"""
     # raise all underflow errors
     np.seterr(all="raise", under="ignore")
 
@@ -23,20 +23,27 @@ def suppressing():
 
 
 def pytest_addoption(parser):
+    """pytest hook to add command line options parsed by pytest"""
     parser.addoption(
         "--runslow", action="store_true", default=False, help="run slow tests"
     )
-
-
-def pytest_configure(config):
-    config.addinivalue_line("markers", "slow: mark test as slow to run")
+    parser.addoption(
+        "--runinteractive",
+        action="store_true",
+        default=False,
+        help="run interactive tests",
+    )
 
 
 def pytest_collection_modifyitems(config, items):
-    if config.getoption("--runslow"):
-        # --runslow given in cli: do not skip slow tests
-        return
+    """pytest hook to filter a collection of tests"""
+    runslow = config.getoption("--runslow", default=False)
+    runinteractive = config.getoption("--runinteractive", default=False)
+
     skip_slow = pytest.mark.skip(reason="need --runslow option to run")
+    skip_interactive = pytest.mark.skip(reason="need --runinteractive option to run")
     for item in items:
-        if "slow" in item.keywords:
+        if "slow" in item.keywords and not runslow:
             item.add_marker(skip_slow)
+        if "interactive" in item.keywords and not runinteractive:
+            item.add_marker(skip_interactive)
