@@ -30,7 +30,7 @@ import numpy as np
 
 from ..grids.base import DimensionError, DomainError, GridBase, discretize_interval
 from ..grids.boundaries.axes import BoundariesData
-from ..grids.cartesian import CartesianGridBase
+from ..grids.cartesian import CartesianGrid
 from ..tools.cache import cached_method
 from ..tools.docstrings import fill_in_docstring
 from ..tools.misc import Number, number_array
@@ -769,6 +769,8 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         result = f"{class_name}(grid={self.grid!r}, data={self.data}"
         if self.label:
             result += f', label="{self.label}"'
+        if self.dtype != np.double:
+            result += f', dtype="{self.dtype}"'
         return result + ")"
 
     def __str__(self) -> str:
@@ -783,7 +785,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
 
     @classmethod
     def random_uniform(
-        cls,
+        cls: Type[TDataField],
         grid: GridBase,
         vmin: float = 0,
         vmax: float = 1,
@@ -791,7 +793,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         label: Optional[str] = None,
         dtype=None,
         rng: np.random.Generator = None,
-    ) -> DataFieldBase:
+    ) -> TDataField:
         """create field with uniform distributed random values
 
         These values are uncorrelated in space.
@@ -830,7 +832,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
 
     @classmethod
     def random_normal(
-        cls,
+        cls: Type[TDataField],
         grid: GridBase,
         mean: float = 0,
         std: float = 1,
@@ -839,7 +841,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         label: Optional[str] = None,
         dtype=None,
         rng: np.random.Generator = None,
-    ) -> DataFieldBase:
+    ) -> TDataField:
         """create field with normal distributed random values
 
         These values are uncorrelated in space. A complex field is returned when either
@@ -896,7 +898,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
 
     @classmethod
     def random_harmonic(
-        cls,
+        cls: Type[TDataField],
         grid: GridBase,
         modes: int = 3,
         harmonic=np.cos,
@@ -905,7 +907,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         label: Optional[str] = None,
         dtype=None,
         rng: np.random.Generator = None,
-    ) -> DataFieldBase:
+    ) -> TDataField:
         r"""create a random field build from harmonics
 
         The resulting fields will be highly correlated in space and can thus
@@ -972,7 +974,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
 
     @classmethod
     def random_colored(
-        cls,
+        cls: Type[TDataField],
         grid: GridBase,
         exponent: float = 0,
         scale: float = 1,
@@ -980,7 +982,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         label: Optional[str] = None,
         dtype=None,
         rng: np.random.Generator = None,
-    ) -> DataFieldBase:
+    ) -> TDataField:
         r"""create a field of random values with colored noise
 
         The spatially correlated values obey
@@ -1042,8 +1044,8 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
 
     @classmethod
     def from_state(
-        cls, attributes: Dict[str, Any], data: np.ndarray = None
-    ) -> DataFieldBase:
+        cls: Type[TDataField], attributes: Dict[str, Any], data: np.ndarray = None
+    ) -> TDataField:
         """create a field from given state.
 
         Args:
@@ -1424,7 +1426,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             )
 
         # determine the points at which data needs to be calculated
-        if isinstance(grid, CartesianGridBase):
+        if isinstance(grid, CartesianGrid):
             # convert Cartesian coordinates to coordinates in current grid
             points = self.grid.transform(grid.cell_coords, "cartesian", "grid")
 
