@@ -43,10 +43,11 @@ class ScalarField(DataFieldBase):
             grid (:class:`~pde.grids.base.GridBase`):
                 Grid defining the space on which this field is defined
             expression (str):
-                Mathematical expression for the scalar value as a function of
-                the position on the grid. The expression may contain standard
-                mathematical functions and it may depend on the axes labels of
-                the grid.
+                Mathematical expression for the scalar value as a function of the
+                position on the grid. The expression may contain standard mathematical
+                functions and it may depend on the axes labels of the grid.
+                More information can be found in the
+                :ref:`expression documentation <documentation-expressions>`.
             label (str, optional):
                 Name of the field
             dtype (numpy dtype):
@@ -57,8 +58,18 @@ class ScalarField(DataFieldBase):
 
         expr = ScalarExpression(expression=expression, signature=grid.axes)
         points = {name: grid.cell_coords[..., i] for i, name in enumerate(grid.axes)}
+
+        try:
+            # try evaluating the expression using a vectorized call
+            data = expr(**points)
+        except ValueError:
+            # if this fails, evaluate expression point-wise
+            data = np.empty(grid.shape)
+            for cells in np.ndindex(*grid.shape):
+                data[cells] = expr(grid.cell_coords[cells])
+
         return cls(  # lgtm [py/call-to-non-callable]
-            grid=grid, data=expr(**points), label=label, dtype=dtype
+            grid=grid, data=data, label=label, dtype=dtype
         )
 
     @classmethod
