@@ -43,8 +43,8 @@ def test_conservative_laplace_sph():
         grid = SphericalSymGrid((r_min, r_max), 8)
         f = ScalarField.from_expression(grid, "cos(r)")
 
-        res1 = f.laplace("natural", conservative=True)
-        res2 = f.laplace("natural", conservative=False)
+        res1 = f.laplace("auto_periodic_neumann", conservative=True)
+        res2 = f.laplace("auto_periodic_neumann", conservative=False)
         np.testing.assert_allclose(res1.data, res2.data, rtol=0.5, atol=0.5)
         np.testing.assert_allclose(res1.integral, 0, atol=1e-12)
 
@@ -69,7 +69,10 @@ def test_small_annulus_sph(op_name, field):
     if field is VectorField:
         f.data[1] = 0
 
-    res = [field(g, data=f.data)._apply_operator(op_name, "natural") for g in grids]
+    res = [
+        field(g, data=f.data)._apply_operator(op_name, "auto_periodic_neumann")
+        for g in grids
+    ]
 
     np.testing.assert_almost_equal(res[0].data, res[1].data, decimal=5)
     assert np.linalg.norm(res[0].data - res[2].data) > 1e-3
@@ -83,8 +86,8 @@ def test_grid_laplace():
     a_1d = ScalarField.from_expression(grid_sph, "cos(r)")
     a_3d = a_1d.interpolate_to_grid(grid_cart)
 
-    b_3d = a_3d.laplace("natural")
-    b_1d = a_1d.laplace("natural")
+    b_3d = a_3d.laplace("auto_periodic_neumann")
+    b_1d = a_1d.laplace("auto_periodic_neumann")
     b_1d_3 = b_1d.interpolate_to_grid(grid_cart)
 
     i = slice(1, -1)  # do not compare boundary points
@@ -98,10 +101,10 @@ def test_gradient_squared(r_inner):
     """compare gradient squared operator"""
     grid = SphericalSymGrid((r_inner, 5), 64)
     field = ScalarField.random_harmonic(grid, modes=1)
-    s1 = field.gradient("natural").to_scalar("squared_sum")
-    s2 = field.gradient_squared("natural", central=True)
+    s1 = field.gradient("auto_periodic_neumann").to_scalar("squared_sum")
+    s2 = field.gradient_squared("auto_periodic_neumann", central=True)
     np.testing.assert_allclose(s1.data, s2.data, rtol=0.1, atol=0.1)
-    s3 = field.gradient_squared("natural", central=False)
+    s3 = field.gradient_squared("auto_periodic_neumann", central=False)
     np.testing.assert_allclose(s1.data, s3.data, rtol=0.1, atol=0.1)
     assert not np.array_equal(s2.data, s3.data)
 
@@ -123,7 +126,7 @@ def test_grid_div_grad_sph():
 def test_poisson_solver_spherical():
     """test the poisson solver on Polar grids"""
     for grid in [SphericalSymGrid(4, 8), SphericalSymGrid([2, 4], 8)]:
-        for bc_val in ["natural", {"value": 1}]:
+        for bc_val in ["auto_periodic_neumann", {"value": 1}]:
             bcs = grid.get_boundary_conditions(bc_val)
             d = ScalarField.random_uniform(grid)
             d -= d.average  # balance the right hand side
