@@ -1,3 +1,4 @@
+# type: ignore
 r"""
 Module collecting functions for handling spherical geometry
 
@@ -91,11 +92,11 @@ def radius_from_volume(volume: TNumArr, dim: int) -> TNumArr:
         float or :class:`~numpy.ndarray`: Radius of the sphere
     """
     if dim == 1:
-        return volume / 2  # type: ignore
+        return volume / 2
     elif dim == 2:
-        return np.sqrt(volume / π)  # type: ignore
+        return np.sqrt(volume / π)
     elif dim == 3:
-        return (3 * volume / (4 * π)) ** (1 / 3)  # type: ignore
+        return (3 * volume / (4 * π)) ** (1 / 3)
     else:
         raise NotImplementedError(f"Cannot calculate the radius in {dim} dimensions")
 
@@ -126,7 +127,7 @@ def make_radius_from_volume_compiled(dim: int) -> Callable[[TNumArr], TNumArr]:
 
     else:
         raise NotImplementedError(f"Cannot calculate the radius in {dim} dimensions")
-    return jit(radius_from_volume)  # type: ignore
+    return jit(radius_from_volume)
 
 
 def volume_from_radius(radius: TNumArr, dim: int) -> TNumArr:
@@ -140,11 +141,11 @@ def volume_from_radius(radius: TNumArr, dim: int) -> TNumArr:
         float or :class:`~numpy.ndarray`: Volume of the sphere
     """
     if dim == 1:
-        return 2 * radius  # type: ignore
+        return 2 * radius
     elif dim == 2:
-        return π * radius ** 2  # type: ignore
+        return π * radius**2
     elif dim == 3:
-        return 4 * π / 3 * radius ** 3  # type: ignore
+        return 4 * π / 3 * radius**3
     else:
         raise NotImplementedError(f"Cannot calculate the volume in {dim} dimensions")
 
@@ -161,21 +162,21 @@ def make_volume_from_radius_compiled(dim: int) -> Callable[[TNumArr], TNumArr]:
     if dim == 1:
 
         def volume_from_radius(radius: TNumArr) -> TNumArr:
-            return 2 * radius  # type: ignore
+            return 2 * radius
 
     elif dim == 2:
 
         def volume_from_radius(radius: TNumArr) -> TNumArr:
-            return π * radius ** 2  # type: ignore
+            return π * radius**2
 
     elif dim == 3:
 
         def volume_from_radius(radius: TNumArr) -> TNumArr:
-            return 4 * π / 3 * radius ** 3  # type: ignore
+            return 4 * π / 3 * radius**3
 
     else:
         raise NotImplementedError(f"Cannot calculate the volume in {dim} dimensions")
-    return jit(volume_from_radius)  # type: ignore
+    return jit(volume_from_radius)
 
 
 def surface_from_radius(radius: TNumArr, dim: int) -> TNumArr:
@@ -190,13 +191,13 @@ def surface_from_radius(radius: TNumArr, dim: int) -> TNumArr:
     """
     if dim == 1:
         if isinstance(radius, np.ndarray):
-            return np.broadcast_to(2, radius.shape)  # type: ignore
+            return np.broadcast_to(2, radius.shape)
         else:
             return 2
     elif dim == 2:
-        return 2 * π * radius  # type: ignore
+        return 2 * π * radius
     elif dim == 3:
-        return 4 * π * radius ** 2  # type: ignore
+        return 4 * π * radius**2
     else:
         raise NotImplementedError(
             f"Cannot calculate the surface area in {dim} dimensions"
@@ -216,9 +217,9 @@ def radius_from_surface(surface: TNumArr, dim: int) -> TNumArr:
     if dim == 1:
         raise RuntimeError("Cannot calculate radius of 1-d sphere from surface")
     elif dim == 2:
-        return surface / (2 * π)  # type: ignore
+        return surface / (2 * π)
     elif dim == 3:
-        return np.sqrt(surface / (4 * π))  # type: ignore
+        return np.sqrt(surface / (4 * π))
     else:
         raise NotImplementedError(f"Cannot calculate the radius in {dim} dimensions")
 
@@ -249,21 +250,21 @@ def make_surface_from_radius_compiled(dim: int) -> Callable[[TNumArr], TNumArr]:
             @nb.generated_jit(nopython=True)
             def surface_from_radius(radius: TNumArr) -> TNumArr:
                 if isinstance(radius, nb.types.Float):
-                    return lambda radius: 2  # type: ignore
+                    return lambda radius: 2
                 else:
-                    return lambda radius: np.full(radius.shape, 2)  # type: ignore
+                    return lambda radius: np.full(radius.shape, 2)
 
     elif dim == 2:
 
         @jit
         def surface_from_radius(radius: TNumArr) -> TNumArr:
-            return 2 * π * radius  # type: ignore
+            return 2 * π * radius
 
     elif dim == 3:
 
         @jit
         def surface_from_radius(radius: TNumArr) -> TNumArr:
-            return 4 * π * radius ** 2  # type: ignore
+            return 4 * π * radius**2
 
     else:
         raise NotImplementedError(
@@ -345,7 +346,7 @@ def haversine_distance(point1: np.ndarray, point2: np.ndarray) -> np.ndarray:
     # spherical coordinates - φ differs by π/4
     factor = (1 - np.cos(λ2 - λ1)) / 2
     arg = (1 - np.cos(φ2 - φ1)) / 2 + np.sin(φ1) * np.sin(φ2) * factor
-    return 2 * r1 * np.arcsin(np.sqrt(arg))  # type: ignore
+    return 2 * r1 * np.arcsin(np.sqrt(arg))
 
 
 def get_spherical_polygon_area(vertices: np.ndarray, radius: float = 1) -> float:
@@ -391,7 +392,7 @@ def get_spherical_polygon_area(vertices: np.ndarray, radius: float = 1) -> float
             * np.tan(0.5 * (s - a_b_dist))
         )
         totalexcess += 4 * np.arctan(np.sqrt(arg))
-    return totalexcess * radius ** 2
+    return totalexcess * radius**2
 
 
 class PointsOnSphere:
@@ -440,7 +441,7 @@ class PointsOnSphere:
                 num_points = 18
             indices = np.arange(0, num_points) + 0.5
             φ = np.arccos(1 - 2 * indices / num_points)
-            θ = π * (1 + 5 ** 0.5) * indices
+            θ = π * (1 + 5**0.5) * indices
 
             # convert to Cartesian coordinates
             points = np.c_[np.cos(θ) * np.sin(φ), np.sin(θ) * np.sin(φ), np.cos(φ)]
@@ -448,7 +449,7 @@ class PointsOnSphere:
         elif num_points is None:
             # use vertices of hypercube in n dimensions
             points = [
-                p  # type: ignore
+                p
                 for p in itertools.product([-1, 0, 1], repeat=dim)
                 if any(c != 0 for c in p)
             ]
@@ -636,7 +637,7 @@ def spherical_harmonic_symmetric(degree: int, θ: float) -> float:
     """
     # note that the definition of `sph_harm` has a different convention for the
     # usage of the variables φ and θ and we thus have to swap the args
-    return np.real(sph_harm(0.0, degree, 0.0, θ))  # type: ignore
+    return np.real(sph_harm(0.0, degree, 0.0, θ))
 
 
 def spherical_harmonic_real(degree: int, order: int, θ: float, φ: float) -> float:
@@ -659,15 +660,15 @@ def spherical_harmonic_real(degree: int, order: int, θ: float, φ: float) -> fl
     if order > 0:
         term1 = sph_harm(order, degree, φ, θ)
         term2 = (-1) ** order * sph_harm(-order, degree, φ, θ)
-        return np.real((term1 + term2) / np.sqrt(2))  # type: ignore
+        return np.real((term1 + term2) / np.sqrt(2))
 
     elif order == 0:
-        return np.real(sph_harm(0, degree, φ, θ))  # type: ignore
+        return np.real(sph_harm(0, degree, φ, θ))
 
     else:  # order < 0
         term1 = sph_harm(-order, degree, φ, θ)
         term2 = (-1) ** order * sph_harm(order, degree, φ, θ)
-        return np.real((term1 - term2) / (complex(0, np.sqrt(2))))  # type: ignore
+        return np.real((term1 - term2) / (complex(0, np.sqrt(2))))
 
 
 def spherical_harmonic_real_k(k: int, θ: float, φ: float) -> float:
@@ -685,3 +686,13 @@ def spherical_harmonic_real_k(k: int, θ: float, φ: float) -> float:
         float: The value of the spherical harmonics
     """
     return spherical_harmonic_real(*spherical_index_lm(k), θ=θ, φ=φ)
+
+
+import warnings
+
+# deprecated the module on 2022-03-08. Scheduled for removal on 2022-09-08
+warnings.warn(
+    "The `spherical` module is deprecated. Some of the functions have been migrated to "
+    "the `droplets.tools.spherical` module of the `py-droplets` package",
+    DeprecationWarning,
+)
